@@ -60,15 +60,12 @@
 #' to specify clusters, see the details section.
 #' @param data A data.frame in which all the variables of \code{formula} can be
 #' interpreted.
-#' @param subset Expression identifying a subset of the rows of the data for
-#' the fitting process.
-#' @param na.action A missing-data filter function, applied to the model.frame,
-#' after any subset argument has been used.  Default is
-#' \code{options()$na.action}.
+#' @param subset Passed as argument \code{subset} to function \code{subset} which applied to \code{data} before the formula is processed.
+#' @param na.action All lines in data with any missing values in the variables of formula are removed.
 #' @param reverse For right censored data, if reverse=TRUE then the censoring
 #' distribution is estimated.
 #' @param conf.int The level (between 0 and 1) for two-sided pointwise
-#' confidence intervals. Defaults to 0.95.
+#' confidence intervals. Defaults to 0.95. Remark: only plain Wald-type confidence limits are available.
 #' @param bandwidth Smoothing parameter for nearest neighborhoods
 #' based on the values of a continuous covariate. See function
 #' \code{neighborhood} for details.
@@ -102,7 +99,6 @@
 #' @seealso \code{\link{predictSurv}}, \code{\link{predictSurvIndividual}},
 #' \code{\link{predictCuminc}}, \code{\link{Hist}}, \code{\link{neighborhood}},
 #' \code{\link{Surv}}, \code{\link{survfit}}, \code{\link{strata}},
-#' \code{\link{cluster}}, \code{\link{NN}}
 #' @references Andersen, Borgan, Gill, Keiding (1993) Springer `Statistical
 #' Models Based on Counting Processes'
 #' 
@@ -118,100 +114,104 @@
 #' Ying, Wei (1994) Journal of Multivariate Analysis 50, 17-29 The Kaplan-Meier
 #' estimate for dependent failure time observations
 #' @keywords survival nonparametric cluster
-#' @examples
-#' 
-#' ##---------------------two-state survival model------------
-#' dat <- SimSurv(30)
-#' with(dat,plot(Hist(time,status)))
-#' fit <- prodlim(Hist(time,status)~1,data=dat)
-#' print(fit)
-#' plot(fit)
-#' summary(fit)
-#' quantile(fit)
-#' 
-#' ## --------------------clustered data---------------------
-#' library(survival)
-#' cdat <- cbind(SimSurv(30),patnr=sample(1:5,size=30,replace=TRUE))
-#' fit <- prodlim(Hist(time,status)~cluster(patnr),data=cdat)
-#' print(fit)
-#' plot(fit)
-#' summary(fit)
-#' 
-#' 
-#' ##-----------compare Kaplan-Meier to survival package---------
-#' 
-#' dat <- SimSurv(30)
-#' pfit <- prodlim(Surv(time,status)~1,data=dat)
-#' pfit <- prodlim(Hist(time,status)~1,data=dat) ## same thing
-#' sfit <- survfit(Surv(time,status)~1,data=dat,conf.type="plain")
-#' ##  same result for the survival distribution function 
-#' all(round(pfit$surv,12)==round(sfit$surv,12))
-#' summary(pfit,digits=3)
-#' summary(sfit,times=quantile(unique(dat$time)))
-#' 
-#' ##-----------estimating the censoring survival function----------------
-#'
-#' rdat <- data.frame(time=c(1,2,3,3,3,4,5,5,6,7),status=c(1,0,0,1,0,1,0,1,1,0))
-#' rpfit <- prodlim(Hist(time,status)~1,data=rdat,reverse=TRUE)
-#' rsfit <- survfit(Surv(time,1-status)~1,data=rdat,conf.type="plain")
-#' ## When there are ties between times at which events are observed
-#' ## times at which subjects are right censored, then the convention
-#' ## is that events come first. This is not obeyed by the above call to survfit,
-#' ## and hence only prodlim delivers the correct reverse Kaplan-Meier:
-#' cbind("Wrong:"=rsfit$surv,"Correct:"=rpfit$surv)
-#' 
-#' ##-------------------stratified Kaplan-Meier---------------------
-#' 
-#' pfit.X2 <- prodlim(Surv(time,status)~X2,data=dat)
-#' summary(pfit.X2)
-#' summary(pfit.X2,intervals=TRUE)
-#' plot(pfit.X2)
-#' 
-#' ##----------continuous covariate: Stone-Beran estimate------------
-#' 
-#' prodlim(Surv(time,status)~X1,data=dat)
-#' 
-#' ##-------------both discrete and continuous covariates------------
-#' 
-#' prodlim(Surv(time,status)~X2+X1,data=dat)
-#' 
-#' ##----------------------interval censored data----------------------
-#' 
-#' dat <- data.frame(L=1:10,R=c(2,3,12,8,9,10,7,12,12,12),status=c(1,1,0,1,1,1,1,0,0,0))
-#' with(dat,Hist(time=list(L,R),event=status))
-#' 
-#' dat$event=1
-#' npmle.fitml <- prodlim(Hist(time=list(L,R),event)~1,data=dat)
-#' 
-#' ##-------------competing risks-------------------
-#' 
-#' CompRiskFrame <- data.frame(time=1:100,event=rbinom(100,2,.5),X=rbinom(100,1,.5))
-#' crFit <- prodlim(Hist(time,event)~X,data=CompRiskFrame)
-#' summary(crFit)
-#' plot(crFit)
-#' summary(crFit,cause=2)
-#' plot(crFit,cause=2)
-#' 
-#' 
-#' # Changing the cens.code:
-#' dat <- data.frame(time=1:10,status=c(1,2,1,2,5,5,1,1,2,2))
-#' fit <- prodlim(Hist(time,status)~1,data=dat)
-#' print(fit$model.response)
-#' fit <- prodlim(Hist(time,status,cens.code="2")~1,data=dat)
-#' print(fit$model.response)
-#' plot(fit)
-#' plot(fit,cause="5")
-#' 
-#' 
-#' ##------------delayed entry----------------------
-#' 
-#' ## left-truncated event times with competing risk endpoint 
-#' 
-#' dat <- data.frame(entry=c(7,3,11,12,11,2,1,7,15,17,3),time=10:20,status=c(1,0,2,2,0,0,1,2,0,2,0))
-#' fitd <- prodlim(Hist(time=time,event=status,entry=entry)~1,data=dat)
-#' summary(fitd)
-#' plot(fitd)
-#'
+##' @examples
+##' 
+##' ##---------------------two-state survival model------------
+##' dat <- SimSurv(30)
+##' with(dat,plot(Hist(time,status)))
+##' fit <- prodlim(Hist(time,status)~1,data=dat)
+##' print(fit)
+##' plot(fit)
+##' summary(fit)
+##' quantile(fit)
+##'
+##' ## Subset
+##' fit1a <- prodlim(Hist(time,status)~1,data=dat,subset=dat$X1==1)
+##' fit1b <- prodlim(Hist(time,status)~1,data=dat,subset=dat$X1==1 & dat$X2>0)
+##' 
+##' ## --------------------clustered data---------------------
+##' library(survival)
+##' cdat <- cbind(SimSurv(30),patnr=sample(1:5,size=30,replace=TRUE))
+##' fit <- prodlim(Hist(time,status)~cluster(patnr),data=cdat)
+##' print(fit)
+##' plot(fit)
+##' summary(fit)
+##' 
+##' 
+##' ##-----------compare Kaplan-Meier to survival package---------
+##' 
+##' dat <- SimSurv(30)
+##' pfit <- prodlim(Surv(time,status)~1,data=dat)
+##' pfit <- prodlim(Hist(time,status)~1,data=dat) ## same thing
+##' sfit <- survfit(Surv(time,status)~1,data=dat,conf.type="plain")
+##' ##  same result for the survival distribution function 
+##' all(round(pfit$surv,12)==round(sfit$surv,12))
+##' summary(pfit,digits=3)
+##' summary(sfit,times=quantile(unique(dat$time)))
+##' 
+##' ##-----------estimating the censoring survival function----------------
+##' 
+##' rdat <- data.frame(time=c(1,2,3,3,3,4,5,5,6,7),status=c(1,0,0,1,0,1,0,1,1,0))
+##' rpfit <- prodlim(Hist(time,status)~1,data=rdat,reverse=TRUE)
+##' rsfit <- survfit(Surv(time,1-status)~1,data=rdat,conf.type="plain")
+##' ## When there are ties between times at which events are observed
+##' ## times at which subjects are right censored, then the convention
+##' ## is that events come first. This is not obeyed by the above call to survfit,
+##' ## and hence only prodlim delivers the correct reverse Kaplan-Meier:
+##' cbind("Wrong:"=rsfit$surv,"Correct:"=rpfit$surv)
+##' 
+##' ##-------------------stratified Kaplan-Meier---------------------
+##' 
+##' pfit.X2 <- prodlim(Surv(time,status)~X2,data=dat)
+##' summary(pfit.X2)
+##' summary(pfit.X2,intervals=TRUE)
+##' plot(pfit.X2)
+##' 
+##' ##----------continuous covariate: Stone-Beran estimate------------
+##' 
+##' prodlim(Surv(time,status)~X1,data=dat)
+##' 
+##' ##-------------both discrete and continuous covariates------------
+##' 
+##' prodlim(Surv(time,status)~X2+X1,data=dat)
+##' 
+##' ##----------------------interval censored data----------------------
+##' 
+##' dat <- data.frame(L=1:10,R=c(2,3,12,8,9,10,7,12,12,12),status=c(1,1,0,1,1,1,1,0,0,0))
+##' with(dat,Hist(time=list(L,R),event=status))
+##' 
+##' dat$event=1
+##' npmle.fitml <- prodlim(Hist(time=list(L,R),event)~1,data=dat)
+##' 
+##' ##-------------competing risks-------------------
+##' 
+##' CompRiskFrame <- data.frame(time=1:100,event=rbinom(100,2,.5),X=rbinom(100,1,.5))
+##' crFit <- prodlim(Hist(time,event)~X,data=CompRiskFrame)
+##' summary(crFit)
+##' plot(crFit)
+##' summary(crFit,cause=2)
+##' plot(crFit,cause=2)
+##' 
+##' 
+##' # Changing the cens.code:
+##' dat <- data.frame(time=1:10,status=c(1,2,1,2,5,5,1,1,2,2))
+##' fit <- prodlim(Hist(time,status)~1,data=dat)
+##' print(fit$model.response)
+##' fit <- prodlim(Hist(time,status,cens.code="2")~1,data=dat)
+##' print(fit$model.response)
+##' plot(fit)
+##' plot(fit,cause="5")
+##' 
+##' 
+##' ##------------delayed entry----------------------
+##' 
+##' ## left-truncated event times with competing risk endpoint 
+##' 
+##' dat <- data.frame(entry=c(7,3,11,12,11,2,1,7,15,17,3),time=10:20,status=c(1,0,2,2,0,0,1,2,0,2,0))
+##' fitd <- prodlim(Hist(time=time,event=status,entry=entry)~1,data=dat)
+##' summary(fitd)
+##' plot(fitd)
+##' #'
 #' @importFrom survival survdiff Surv cluster
 #' @importFrom stats quantile
 #' @import lava
@@ -220,8 +220,8 @@
 ## --> import From KernSmooth dpik
 "prodlim" <- function(formula,
                       data = parent.frame(),
-                      subset=NULL,
-                      na.action=options()$na.action,
+                      subset,
+                      na.action=NULL,
                       reverse=FALSE,
                       conf.int=.95,
                       bandwidth=NULL,
@@ -238,13 +238,17 @@
 
     # {{{  find the data
     call <- match.call()
-    Strata <- function(x)x
+    if (!missing(subset))
+        data <- subset(data,subset=subset)
     EHF <- EventHistory.frame(formula=formula,
                               data=data,
                               unspecialsDesign=FALSE,
                               specials=c("Strata","strata","factor", "NN","cluster"),
-                              subset =subset,
-                              na.action=na.action)
+                              stripSpecials=c("strata","cluster"),
+                              stripAlias=list("strata"=c("Strata","factor")),
+                              stripArguments=list("strata"=NULL,"NN"=NULL,"cluster"=NULL),
+                              specialsDesign=FALSE,
+                              check.formula=TRUE)
     event.history <- EHF$event.history
     response <- EHF$event.history
     if (reverse==TRUE){      ## estimation of censoring distribution
@@ -265,7 +269,7 @@
     # {{{  covariates
 
     covariates <- EHF[-1]
-    ##  `factor', 'Strata' and 'dummy' are aliases for `strata'
+    ##  `factor' and 'Strata' are aliases for `strata'
     strata.pos <- match(c("strata","factor","Strata"),names(covariates),nomatch=0)
     if (sum(strata.pos)>0)
         strata <- do.call("cbind",covariates[strata.pos])
